@@ -1,9 +1,10 @@
 # Part of the PsychoPy library
-# Copyright (C) 2011 Jonathan Peirce
+# Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 from ctypes import *
-import pyglet.gl as GL
+import pyglet
+GL=pyglet.gl
 import sys
 
 def print_log(shader):
