@@ -1,27 +1,27 @@
 #!/usr/bin/env python
 
-#The most accurate way to time your stimulus presentation is to 
-#present for a certain number of frames. For that to work you need 
-#your window flips to synchronise to the monitor and not to drop 
+#The most accurate way to time your stimulus presentation is to
+#present for a certain number of frames. For that to work you need
+#your window flips to synchronise to the monitor and not to drop
 #any frames. This script examines the precision of your frame flips.
 
-#Shut down as many applications as possible, especially those that 
+#Shut down as many applications as possible, especially those that
 #might try to update
 
-from psychopy import visual, log, core, event
+from psychopy import visual, logging, core, event
 import matplotlib
-matplotlib.use('WXAgg')
+#matplotlib.use('WXAgg')#change this to control the plotting 'back end'
 import pylab
 
 nIntervals=1000
 win = visual.Window([1280,1024], fullscr=True, allowGUI=False, waitBlanking=True)
-progBar = visual.PatchStim(win, tex=None, mask=None, 
+progBar = visual.PatchStim(win, tex=None, mask=None,
     size=[0,0.05],color='red',pos=[0,-0.9],
     autoLog=False)
-myStim = visual.PatchStim(win, tex='sin', mask='gauss', 
+myStim = visual.PatchStim(win, tex='sin', mask='gauss',
     size=300,sf=0.05, units='pix',
     autoLog=False)
-#log.console.setLevel(log.INFO)#uncomment if you want to print every frame time
+#logging.console.setLevel(logging.INFO)#uncomment if you want to print every frame time
 
 win.setRecordFrameIntervals()
 for frameN in range(nIntervals+1):
@@ -32,7 +32,7 @@ for frameN in range(nIntervals+1):
     if event.getKeys():
         print 'stopped early'
         break
-    win.logOnFlip(msg='frame=%i' %frameN, level=log.EXP)
+    win.logOnFlip(msg='frame=%i' %frameN, level=logging.EXP)
     win.flip()
 win.close()
 
