@@ -3,14 +3,14 @@
 See demo_mouse.py and i{demo_joystick.py} for examples
 """
 # Part of the PsychoPy library
-# Copyright (C) 2011 Jonathan Peirce
+# Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 # 01/2011 modified by Dave Britton to get mouse event timing
 
 import sys, time, copy
 import psychopy.core, psychopy.misc
-from psychopy import log
+from psychopy import logging
 from psychopy.constants import *
 import string, numpy
 
@@ -24,7 +24,7 @@ except:
     havePygame = False
 
 try:
-    import pyglet.window
+    import pyglet
     havePyglet = True
 except:
     havePyglet = False
@@ -49,17 +49,30 @@ if havePyglet:
     #eventThread = _EventDispatchThread()
     #eventThread.start()
 
-def _onPygletKey(symbol, modifiers):
-    """handler for on_key_press events from pyglet
-    Adds a key event to global _keyBuffer which can then be accessed as normal
-    using event.getKeys(), .waitKeys(), clearBuffer() etc...
-    Appends a tuple with (keyname, timepressed) into the _keyBuffer"""
+def _onPygletKey(symbol, modifiers, emulated=False):
+    """handler for on_key_press pyglet events, or call directly to emulate a key press
+    
+    Appends a tuple with (keyname, timepressed) into the global _keyBuffer. The
+    _keyBuffer can then be accessed as normal using event.getKeys(), .waitKeys(),
+    clearBuffer(), etc.
+    
+    J Gray 2012: Emulated means add a key (symbol) to the buffer virtually.
+    This is useful for fMRI_launchScan, and for unit testing (in testTheApp)
+    Logging distinguished EmulatedKey events from real Keypress events.
+    For emulation, the key added to the buffer is unicode(symbol), instead of
+    pyglet.window.key.symbol_string(symbol)
+    """
     keyTime=psychopy.core.getTime() #capture when the key was pressed
-    thisKey = pyglet.window.key.symbol_string(symbol).lower()#convert symbol into key string
-    #convert pyglet symbols to pygame forms ( '_1'='1', 'NUM_1'='[1]')
-    thisKey = (thisKey.lstrip('_').lstrip('NUM_'),keyTime) # modified to capture time of keypress so key=(keyname,keytime)
-    _keyBuffer.append(thisKey)
-    log.data("Keypress: %s" %thisKey[0])
+    if emulated:
+        thisKey = unicode(symbol)
+        keySource = 'EmulatedKey'
+    else:
+        thisKey = pyglet.window.key.symbol_string(symbol).lower() #convert symbol into key string
+        #convert pyglet symbols to pygame forms ( '_1'='1', 'NUM_1'='[1]')
+        thisKey = thisKey.lstrip('_').lstrip('NUM_')
+        keySource = 'Keypress'
+    _keyBuffer.append( (thisKey,keyTime) ) # tuple
+    logging.data("%s: %s" % (keySource, thisKey))
 
 def _onPygletMousePress(x,y, button, modifiers):
     global mouseButtons, mouseClick, mouseTimes
@@ -75,7 +88,7 @@ def _onPygletMousePress(x,y, button, modifiers):
         mouseButtons[2]=1
         mouseTimes[2]= psychopy.core.getTime()-mouseClick[2].timeAtLastReset
         label='Right'
-    log.data("Mouse: %s button down, pos=(%i,%i)" %(label, x,y))
+    logging.data("Mouse: %s button down, pos=(%i,%i)" %(label, x,y))
 
 def _onPygletMouseRelease(x,y, button, modifiers):
     global mouseButtons
@@ -88,12 +101,12 @@ def _onPygletMouseRelease(x,y, button, modifiers):
     if button == pyglet.window.mouse.RIGHT:
         mouseButtons[2]=0
         label='Right'
-    log.data("Mouse: %s button up, pos=(%i,%i)" %(label, x,y))
+    logging.data("Mouse: %s button up, pos=(%i,%i)" %(label, x,y))
 
 def _onPygletMouseWheel(x,y,scroll_x, scroll_y):
     global mouseWheelRel
     mouseWheelRel = mouseWheelRel+numpy.array([scroll_x, scroll_y])
-    log.data("Mouse: wheel shift=(%i,%i), pos=(%i,%i)" %(scroll_x, scroll_y,x,y))
+    logging.data("Mouse: wheel shift=(%i,%i), pos=(%i,%i)" %(scroll_x, scroll_y,x,y))
 
 def _onPygletMouseMotion(x, y, dx, dy): # will this work? how are pyglet event handlers defined?
     global mouseMove
@@ -256,7 +269,7 @@ def waitKeys(maxWait = None, keyList=None):
 
     #after the wait period or received a valid keypress
     if key:
-        log.data("Key pressed: %s" %key)
+        logging.data("Key pressed: %s" %key)
         return [key]#need to convert back to a list
     else:
         return None #no keypress in period
@@ -294,10 +307,12 @@ class Mouse:
         self.mouseClock=psychopy.core.Clock() # used for movement timing
         self.movedistance=0.0
         #if pygame isn't initialised then we must use pyglet
+        global usePygame
         if (havePygame and not pygame.display.get_init()):
-            global usePygame
             usePygame=False
-
+        if not usePygame:
+            global mouseButtons
+            mouseButtons = [0,0,0]
         if newPos is not None: self.setPos(newPos)
 
     def setPos(self,newPos=(0,0)):
@@ -313,7 +328,6 @@ class Mouse:
         if usePygame:
             newPosPix[1] = self.win.size[1]/2-newPosPix[1]
             newPosPix[0] = self.win.size[0]/2+newPosPix[0]
-            print newPosPix
             mouse.set_pos(newPosPix)
         else: print "pyglet does not support setting the mouse position yet"
 
@@ -446,6 +460,7 @@ class Mouse:
         global mouseClick
         for c in buttons:
             mouseClick[c].reset()
+            mouseTimes[c]=0.0
 
     def getPressed(self, getTime=False):
         """Returns a 3-item list indicating whether or not buttons 1,2,3 are currently pressed
