@@ -17,10 +17,10 @@ for examples see the demos menu of the PsychoPy Coder or go to the URL above.
 
 """
 # Part of the PsychoPy library
-# Copyright (C) 2011 Jonathan Peirce
+# Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
-from psychopy import log
+from psychopy import logging
 try:
     from ioLabs import *
 except:
@@ -29,4 +29,4 @@ python (not the Standalone distribution of PsychoPy) then try installing it with
     > easy_install ioLabs
     
 """
-    log.error(msg)
+    logging.error(msg)
