@@ -1,10 +1,10 @@
 # Part of the PsychoPy library
-# Copyright (C) 2011 Jonathan Peirce
+# Copyright (C) 2012 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 """
 placeholder for adding c (or ctypes) extensions to the linux PsychoPy
 """
-from psychopy import log
+from psychopy import logging
 import sys
 try:
     import ctypes, ctypes.util
@@ -12,7 +12,7 @@ try:
     importCtypesFailed = False
 except:
     importCtypesFailed = True
-    log.debug("rush() not available because import ctypes, ctypes.util failed in ext/linux.py")
+    logging.debug("rush() not available because import ctypes, ctypes.util failed in ext/linux.py")
     
 #FIFO and RR(round-robin) allow highest priority for realtime
 SCHED_NORMAL=0
@@ -43,7 +43,7 @@ def rush(value=True):
         schedParams.sched_priority = c.sched_get_priority_max(SCHED_RR)
         err = c.sched_setscheduler(0,SCHED_RR, ctypes.byref(schedParams))
         if err==-1:#returns 0 if OK
-            log.warning("""Failed to raise thread priority with sched_setscheduler.
+            logging.warning("""Failed to raise thread priority with sched_setscheduler.
 To enable rush(), if you are using a debian-based linux, try this in a terminal window:
   'sudo setcap cap_sys_nice=eip %s'  [NB: You may need to install 'setcap' first.]
 If you are using the system's python (eg /usr/bin/python2.x), its highly recommended
@@ -54,7 +54,7 @@ to change cap_sys_nice back to normal afterwards:
         schedParams.sched_priority = c.sched_get_priority_min(SCHED_NORMAL)
         err = c.sched_setscheduler(0,SCHED_NORMAL, ctypes.byref(schedParams))
         if err==-1:#returns 0 if OK
-            log.warning("""Failed to set thread priority back to normal level with sched_setscheduler.
+            logging.warning("""Failed to set thread priority back to normal level with sched_setscheduler.
 Try:  'sudo setcap cap_sys_nice= %s'""" % (sys.executable))
     
     return True
