@@ -1,11 +1,11 @@
 import glob
-from psychopy import core, log, hardware
+from psychopy import core, logging, hardware
 
-log.console.setLevel(log.DEBUG)
+logging.console.setLevel(logging.DEBUG)
 
 pr655 = hardware.findPhotometer(device='PR655')
 if pr655==None:
-    log.warning('no device found')
+    logging.warning('no device found')
 else:
     print 'type:', pr655.type
     print 'SN:', pr655.getDeviceSN()
